@@ -12,10 +12,11 @@ our @EXPORT_OK = qw( tcc_inline tcc_eval );
 our @EXPORT = @EXPORT_OK;
 
 # ABSTRACT: Embed Tiny C code in your Perl program
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 my $ffi = FFI::Platypus->new;
+$ffi->load_custom_type( 'StringArray' => 'string_array' );
 
 # TODO: support platypus types like pointers and arrays
 my %typemap = (
@@ -58,13 +59,9 @@ sub _generate_sub ($$$)
   && $func->{arg_types}->[0] eq 'int'
   && $func->{arg_types}->[1] =~ /^(const |)char \*\*$/)
   {
-    my $f = $ffi->function($address => ['int','opaque'] => _typemap $func->{return_type});
+    my $f = $ffi->function($address => ['int','string_array'] => _typemap $func->{return_type});
     $sub = sub {
-      my $argc = scalar @_;
-      my @c_strings = map { "$_\0" } @_;
-      my $ptrs = pack 'P' x $argc, @c_strings;
-      my $argv = unpack 'L!', pack 'P', $ptrs;
-      $f->call($argc, $argv);
+      $f->call(scalar @_, \@_);
     };
   }
   else
@@ -318,7 +315,7 @@ FFI::TinyCC::Inline - Embed Tiny C code in your Perl program
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
